@@ -1,4 +1,4 @@
-//  $Id: bfgs_min.cpp,v 1.5 2008/07/08 15:28:14 keb Exp $
+//  $Id: bfgs_min.cpp,v 1.14 2008/08/21 09:54:05 nds65 Exp $
 //  =================================================================
 //
 //   CCP4 Coordinate Library: support of coordinate-related
@@ -621,6 +621,8 @@ realtype Alpha, NewtLn, S, InitSp, RelLng, MinLam;
 realtype Lambda,LamTem, LamPre, FplPre, A, B;
 realtype Disc,  B1, B2, Lambda0;
 
+ LamPre = FplPre = 0.0;  // to avoid them being undefined when
+                         // computing B1 and B2
   MaxTkn  = False;
   RetCode = 2;
   Alpha   = 1.0e-4;
