@@ -1,4 +1,4 @@
-//  $Id: file_.cpp,v 1.19 2008/07/08 15:28:14 keb Exp $
+//  $Id: file_.cpp,v 1.20.2.2 2009/07/01 10:58:09 ccb Exp $
 //  =================================================================
 //
 //   CCP4 Coordinate Library: support of coordinate-related
@@ -76,7 +76,7 @@
 // ===================  Auxilary Functions  =========================
 
 pstr GetFPath ( pstr FilePath, int syskey )  {
-pstr P;
+pstr P = NULL;
   if (syskey==syskey_unix)     
     P = strrchr(FilePath,'/');
   else if (syskey==syskey_win) 
@@ -94,7 +94,7 @@ pstr P;
 }
 
 cpstr GetFName ( cpstr FilePath, int syskey )  {
-pstr P;
+pstr P = NULL;
   if (syskey==syskey_unix)     
     P = strrchr(FilePath,'/');
   else if (syskey==syskey_win) 
@@ -347,10 +347,10 @@ int  i;
           if (i>0)  sleep ( 1 );
 #endif
           if (TextMode)  {
-            if (ReadOnly)  hFile = fopen ( FName,"r"   );
+            if (ReadOnly)  hFile = fopen ( FName,"rt"   );
                      else  hFile = fopen ( FName,"r+t" );
           } else  {
-            if (ReadOnly)  hFile = fopen ( FName,"r"   );
+            if (ReadOnly)  hFile = fopen ( FName,"rb"   );
                      else  hFile = fopen ( FName,"r+b" );
           }
 #ifndef _MVS
@@ -678,7 +678,10 @@ Boolean  HSuccess = IOSuccess;
     }
     if (TextMode)  {
       Line[0] = char(0);
-      fgets ( Line,MaxLen,hFile );
+      if (!fgets ( Line,MaxLen,hFile )) {
+	IOSuccess = False;
+	return 0;
+      }
       LCnt = strlen(Line);
       while (LCnt>0)  {
         if ((Line[LCnt-1]!='\n') &&
@@ -970,7 +973,6 @@ word  CFile::ReadTerLine ( pstr Line, Boolean longLine )  {
 wordUniBin wUB;
 word       ll;
 byte       sl;
-Boolean    B;
   if (!longLine)  {
     ReadFile ( &sl,sizeof(sl) );
     ll = sl;
