@@ -1,4 +1,4 @@
-//  $Id: mmdb_sbase0.cpp,v 1.8 2008/07/08 15:28:16 keb Exp $
+//  $Id: mmdb_sbase0.cpp,v 1.12.2.1 2009/07/01 10:52:19 ccb Exp $
 //  =================================================================
 //
 //   CCP4 Coordinate Library: support of coordinate-related
@@ -738,7 +738,7 @@ int  superpose_atoms ( mat44 & T, PPCSBAtom A1, PPCAtom A2, int nAtoms,
 // superposes exactly the atoms A1[0] and A2[0].
 realtype det,B;
 vect3    vc1,vc2;
-int      i,j,k,i1,i2;
+ int      i,j,k;
 
   //  1.  Calculate the correlation matrix. The rotation will be
   //      done around
@@ -1320,7 +1320,11 @@ PPCSBIndex Index1;
     dirpath = new char[i+10];
     strcpy ( dirpath,path );
     if (i>0)  {
+#if defined(_MSC_VER) || defined (WIN32)
+      if (dirpath[i-1]!='\\')  strcat ( dirpath,"\\" );
+#else
       if (dirpath[i-1]!='/')  strcat ( dirpath,"/" );
+#endif
     }
   }
 
@@ -1486,6 +1490,8 @@ int MakeElementType ( int ElType, char chirality, Boolean Cflag )  {
 int CSBase0::GetStructNo ( cpstr compoundID )  {
 int  l1,l2,l,k;
 char id[20];
+
+  l = k = 0; // otherwise l and k might be undefined
   strcpy_css ( id,compoundID );
   l1 = 0;
   l2 = nStructures-1;
@@ -3088,4 +3094,3 @@ int           i,structNo;
   return SBASE_Ok;
 
 }
-
