@@ -1,4 +1,4 @@
-//  $Id: mmdb_title.cpp,v 1.10 2008/07/08 15:28:16 keb Exp $
+//  $Id: mmdb_title.cpp,v 1.16.2.3 2010/01/16 13:30:53 rmk65 Exp $
 //  =================================================================
 //
 //   CCP4 Coordinate Library: support of coordinate-related
@@ -1381,6 +1381,10 @@ MakeStreamFunctions(CRemark)
 #define  R350_CHAINS         2
 #define  R350_BIOMT          3
 
+#ifdef _WIN32
+#define  strcasestr(s, t) strstr(strupr(s), t)
+#endif
+
 void getRemarkKey ( RPCRemark rem, int & lkey )  {
   if (rem)  {
     if (rem->remarkNum!=350)  lkey = R350_END;
